| get_monitors | R Documentation |
Get monitors
get_monitors( api_key, logs = FALSE, all_uptime_ratio = FALSE, all_time_uptime_durations = FALSE, custom_uptime_ratios = NULL, response_times = FALSE )
api_key |
The api_key |
logs |
Should the logs be returned (default FALSE) |
all_uptime_ratio |
Uptime ratio since monitoring began (default FALSE). |
all_time_uptime_durations |
All time uptime durations (default FALSE). |
custom_uptime_ratios |
Defines the number of days to calculate the uptime ratio(s) for. Ex: custom_uptime_ratios=7-30-45 to get the uptime ratios for those periods. |
response_times |
Logical default |
The argument order may change. So use named arguments. I also want to make this function to always return a tibble with the same number of columns. However, the api itself isn't really consistent and depends on the arguments passed.
https://uptimerobot.com/api
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.